@@ -1,11 +1,11 @@
-/* 
+/*
  * GChemUtils GOffice component
- * gchempaint.h 
+ * gchempaint.h
  *
  * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -24,9 +24,11 @@
 #define GOFFICE_GCHEMUTILS_PRIV_H
 
 #include "gchemutils.h"
+#include <gcu/chem3ddoc.h>
+#include <gcu/structs.h>
 #include <gogcuapp.h>
 #include <gcu/document.h>
-#include <gcu/window.h>
+#include <gcugtk/window.h>
 
 struct _GOGChemUtilsComponent
 {
@@ -34,7 +36,12 @@ struct _GOGChemUtilsComponent
 
 	GOGcuApplication *application;
 	gcu::Document *document;
-	gcu::Window *window; // TODO use a gcu::Window.
+	gcugtk::Window *window; // TODO use a gcu::Window.
+	gcu::ContentType type;
+	gcu::Display3DMode mode;
+	double psi, theta, phi; // only used by the chem3d code
+	char *data; // only used by the chem3d code
+	size_t length; // only used by the chem3d code
 };
 
 
