@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * application.cc 
+ * application.cc
  *
  * Copyright (C) 2004-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -52,11 +52,14 @@
 #include "target.h"
 #include "view.h"
 #include "window.h"
+#include "widgetdata.h"
 #include "zoomdlg.h"
+#include <gcugtk/ui-manager.h>
+#include <gcugtk/filechooser.h>
 #include <gcu/cmd-context.h>
-#include <gcu/filechooser.h>
 #include <gcu/loader.h>
 #include <gcu/loader-error.h>
+#include <gccv/canvas.h>
 #include <glib/gi18n-lib.h>
 #include <fstream>
 #include <cstring>
@@ -149,7 +152,7 @@ static void load_globs ()
       const char *end_ptr;
       char *dir;
       int len;
- 
+
       end_ptr = ptr;
       while (*end_ptr != ':' && *end_ptr != '\000')
 	end_ptr ++;
@@ -180,6 +183,7 @@ namespace gcp {
 class ApplicationPrivate {
 public:
 	static bool Init (Application *app);
+	static Object* CreateBrackets ();
 };
 
 bool ApplicationPrivate::Init (Application *app)
@@ -221,6 +225,11 @@ bool ApplicationPrivate::Init (Application *app)
 }
 
 // Objects creation static methods
+Object* ApplicationPrivate::CreateBrackets ()
+{
+	return new Brackets ();
+}
+
 static Object* CreateAtom ()
 {
 	return new Atom ();
@@ -301,11 +310,6 @@ static Object* CreateElectron ()
 	return new Electron (NULL, false);
 }
 
-static Object* CreateBrackets ()
-{
-	return new Brackets ();
-}
-
 bool	Application::m_bInit = false;
 bool	Application::m_Have_InChI = false;
 bool	Application::m_HaveGhemical = false;
@@ -317,8 +321,8 @@ static void on_config_changed (GOConfNode *node, gchar const *key, Application *
 	app->OnConfigChanged (node, key);
 }
 
-Application::Application (CmdContext *cc):
-	gcu::Application ("GChemPaint", DATADIR, "gchempaint", "gchempaint", cc)
+Application::Application (gcugtk::CmdContextGtk *cc):
+	gcugtk::Application ("GChemPaint", DATADIR, "gchempaint", "gchempaint", cc)
 {
 	m_CurZ = 6;
 	m_pActiveDoc = NULL;
@@ -330,7 +334,7 @@ Application::Application (CmdContext *cc):
 		/* Initialize plugins manager */
 		gcu::Loader::Init (this);
 /*		OBConversion Conv;
-		m_Have_InChI = Conv.FindFormat ("inchi") != NULL || 
+		m_Have_InChI = Conv.FindFormat ("inchi") != NULL ||
 			(g_spawn_command_line_sync ("which main_inchi", &result, &errors, NULL, NULL)
 			&& result && strlen (result));
 		if (result)
@@ -359,7 +363,7 @@ Application::Application (CmdContext *cc):
 		AddType ("fragment", CreateFragment, FragmentType);
 		ElectronType = AddType ("electron", CreateElectron);
 		Object::AddAlias (ElectronType, "electron-pair");
-		BracketsType = AddType ("brackets", CreateBrackets);
+		BracketsType = AddType ("brackets", ApplicationPrivate::CreateBrackets);
 		// Add rules
 		AddRule ("reaction", RuleMustContain, "reaction-step");
 		AddRule ("reaction-step", RuleMustContain, "reactant");
@@ -373,6 +377,7 @@ Application::Application (CmdContext *cc):
 		AddRule ("reaction-prop", RuleMayContain, "text");
 		AddRule ("reaction-operator", RuleMustBeIn, "reaction-step");
 		AddRule ("reactant", RuleMayContain, "molecule");
+		AddRule ("reactant", RuleMayContain, "text");
 		AddRule ("mesomer", RuleMustContain, "molecule");
 		AddRule ("mesomer", RuleMustBeIn, "mesomery");
 		AddRule ("mesomery", RuleMustContain, "mesomer");
@@ -388,17 +393,20 @@ Application::Application (CmdContext *cc):
 		OnDeleteSignal = Object::CreateNewSignalId ();
 		OnThemeChangedSignal = Object::CreateNewSignalId ();
 
+#if 0
 		/* get the theme style for labels so that tools buttons colors might
 		be adapted to the current theme */
 		GtkWidget *w = gtk_label_new ("");
-		m_Style = GTK_STYLE (g_object_ref (gtk_rc_get_style (w)));
+		GtkStyleContext *ctxt = gtk_widget_get_style_context (w);
 		g_object_ref_sink (w);
 		g_object_unref (w);
+#endif
 
 		// load settings before plugins
 		m_ConfNode = go_conf_get_node (GetConfDir (), GCP_CONF_DIR_SETTINGS);
 		GCU_GCONF_GET ("compression", int, CompressionLevel, 0)
 		GCU_GCONF_GET ("invert-wedge-hashes", bool, InvertWedgeHashes, false)
+		GCU_GCONF_GET ("use-atom-colors", bool, m_UseAtomColors, false)
 		bool CopyAsText;
 		GCU_GCONF_GET ("copy-as-text", bool, CopyAsText, false)
 		ClipboardFormats = CopyAsText? GCP_CLIPBOARD_ALL: GCP_CLIPBOARD_NO_TEXT;
@@ -407,7 +415,7 @@ Application::Application (CmdContext *cc):
 		// load plugins
 		Plugin::LoadPlugins ();
 		m_bInit = true;
-		g_idle_add (reinterpret_cast <GSourceFunc> (ApplicationPrivate::Init), this); 
+		g_idle_add (reinterpret_cast <GSourceFunc> (ApplicationPrivate::Init), this);
 	}
 	RadioActions = NULL;
 	m_entries = 0;
@@ -434,12 +442,13 @@ Application::Application (CmdContext *cc):
 		found = Loader::GetNextLoader (it);
 	}
 	// test if OpenBabel supports some extra types
-	TestSupportedType ("chemical/x-mdl-molfile");
-	TestSupportedType ("chemical/x-pdb");
-	TestSupportedType ("chemical/x-xyz");
-	TestSupportedType ("chemical/x-ncbi-asn1");
-	TestSupportedType ("chemical/x-ncbi-asn1-binary");
-	TestSupportedType ("chemical/x-ncbi-asn1-xml");
+//	TestSupportedType ("chemical/x-mdl-molfile");
+	TestSupportedType ("chemical/x-pdb", "pdb", true);
+	TestSupportedType ("chemical/x-xyz", "xyz", true);
+//	TestSupportedType ("chemical/x-ncbi-asn1");
+//	TestSupportedType ("chemical/x-ncbi-asn1-binary");
+	TestSupportedType ("chemical/x-ncbi-asn1-xml", "pc", false);
+	TestSupportedType ("chemical/x-inchi", "inchi", true);
 	// now read extra types declared by the user
 	char *home = getenv ("HOME");
 	if (home) {
@@ -453,7 +462,7 @@ Application::Application (CmdContext *cc):
 				TestSupportedType (line);
 		}
 	}
-	
+
 	// make themes permanent with this as a dummy client
 	list <string> Names = TheThemeManager.GetThemesNames ();
 	list <string>::iterator j, jend = Names.end ();
@@ -492,13 +501,21 @@ Application::~Application ()
 	go_conf_free_node (m_ConfNode);
 	m_ConfNode = NULL;
 	TheThemeManager.Shutdown ();
+#if 0
 	g_object_unref (m_Style);
+#endif
 	// unref cursors
 	for (int i = 0; i < CursorMax; i++)
 		gdk_cursor_unref (m_Cursors[i]);
 	if (m_entries)
 		g_free (RadioActions);
 	g_object_unref (IconFactory);
+	// unload plugins
+	Plugin::UnloadPlugins ();
+	std::map < std::string, gccv::Canvas * >::iterator k, kend = m_ToolCanvases.end ();
+	for (k = m_ToolCanvases.begin (); k != kend; k++)
+		delete (*k).second;
+	m_ToolCanvases.clear ();
 }
 
 void Application::ActivateTool (const string& toolname, bool activate)
@@ -515,7 +532,7 @@ void Application::ActivateTool (const string& toolname, bool activate)
 					gtk_toggle_tool_button_set_active (button, true);
 				Tools *ToolsBox = dynamic_cast<Tools*> (GetDialog ("tools"));
 				if (ToolsBox)
-					ToolsBox->OnSelectTool (m_pActiveTool);		
+					ToolsBox->OnSelectTool (m_pActiveTool);
 			}
 		} else {
 			if (m_pActiveTool == m_Tools[toolname])
@@ -528,7 +545,7 @@ void Application::ActivateTool (const string& toolname, bool activate)
 void Application::ClearStatus ()
 {
 	if (m_pActiveDoc) {
-		Window *Win = m_pActiveDoc->GetWindow ();
+		Window *Win = static_cast < Window * > (m_pActiveDoc->GetWindow ());
 		if (Win)
 			Win->ClearStatus ();
 	}
@@ -537,7 +554,7 @@ void Application::ClearStatus ()
 void Application::SetStatusText (const char* text)
 {
 	if (m_pActiveDoc) {
-		Window *Win = m_pActiveDoc->GetWindow ();
+		Window *Win = static_cast < Window * > (m_pActiveDoc->GetWindow ());
 		if (Win)
 			Win->SetStatusText (text);
 	}
@@ -545,7 +562,7 @@ void Application::SetStatusText (const char* text)
 
 void Application::OnSaveAs ()
 {
-	FileChooser (this, true, m_WriteableMimeTypes, m_pActiveDoc);
+	gcugtk::FileChooser (this, true, m_WriteableMimeTypes, m_pActiveDoc);
 }
 
 enum {
@@ -708,7 +725,7 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 			OpenGcp (filename2, pDoc);
 		else {
 			// FIXME: rewrite this code
-			ContentType type = Load (filename2, mime_type, pDoc);
+			ContentType type = Load (filename2, mime_type, pDoc, "--gen2D");
 			if (type != ContentTypeUnknown) {
 				switch (type) {
 				case ContentType3D: {
@@ -744,7 +761,7 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 				pDoc->GetView ()->Update (pDoc);
 				pDoc->GetView ()->EnsureSize ();
 				if (pDoc->GetWindow ())
-					pDoc->GetWindow ()->ActivateActionWidget ("/MainMenu/FileMenu/SaveAsImage", pDoc->HasChildren ());
+					static_cast < Window * > (m_pActiveDoc->GetWindow ())->ActivateActionWidget ("/MainMenu/FileMenu/SaveAsImage", pDoc->HasChildren ());
 			}
 		}
 	}
@@ -796,6 +813,7 @@ void Application::OpenGcp (string const &filename, Document* pDoc)
 	GError *error = NULL;
 	GFileInfo *info = NULL;
 	bool create = false;
+	pDoc->SetUseAtomColors (false); // the default for a document
 	try
 	{
 		if (!filename.length ())
@@ -821,7 +839,7 @@ void Application::OpenGcp (string const &filename, Document* pDoc)
 			throw 1;
 		}
 		xmlKeepBlanksDefault (1); // to be sure we don't loose significant spaces.
-		if (!(xml = xmlReadIO ((xmlInputReadCallback) cb_vfs_to_xml, 
+		if (!(xml = xmlReadIO ((xmlInputReadCallback) cb_vfs_to_xml,
 				 (xmlInputCloseCallback) g_input_stream_close, input, filename.c_str (), NULL, 0))) {
 			g_object_unref (file);
 			throw 1;
@@ -889,6 +907,7 @@ void Application::OpenGcp (string const &filename, Document* pDoc)
 		gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
 		g_signal_connect_swapped (G_OBJECT (message), "response", G_CALLBACK (gtk_widget_destroy), G_OBJECT (message));
 		gtk_widget_show(message);
+		pDoc->SetUseAtomColors (m_UseAtomColors); // the file is new, so it should follow the app default
 	}
 }
 
@@ -912,7 +931,7 @@ void Application::OnSaveAsImage ()
 	l.push_front ("application/pdf");
 	l.push_front ("image/x-eps");
 	l.push_front ("image/svg+xml");
-	FileChooser (this, true, l, m_pActiveDoc, _("Save as image"), GetImageResolutionWidget ());
+	gcugtk::FileChooser (this, true, l, m_pActiveDoc, _("Save as image"), GetImageResolutionWidget ());
 }
 
 void Application::Zoom (double zoom)
@@ -924,7 +943,7 @@ void Application::Zoom (double zoom)
 	else {
 		Dialog *pDialog = GetDialog ("Zoom");
 		if (pDialog)
-			gtk_window_present (pDialog->GetWindow ()); 
+			pDialog->Present ();
 		else
 			new ZoomDlg (m_pActiveDoc);
 	}
@@ -956,7 +975,7 @@ void Application::OnToolChanged (GtkAction *current)
 	m_pActiveTool = m_Tools[gtk_action_get_name (current)];
 	Tools *ToolsBox = dynamic_cast<Tools*> (GetDialog ("tools"));
 	if (ToolsBox)
-		ToolsBox->OnSelectTool (m_pActiveTool);		
+		ToolsBox->OnSelectTool (m_pActiveTool);
 	if (m_pActiveTool)
 		m_pActiveTool->Activate(true);
 }
@@ -968,14 +987,14 @@ void Application::BuildTools () throw (std::runtime_error)
 	list<char const*>::iterator j, jend = UiDescs.end ();
 	string s;
 	GError *error = NULL;
-	GtkUIManager *ToolsManager = gtk_ui_manager_new ();
+	gcugtk::UIManager *ToolsManager = new gcugtk::UIManager (gtk_ui_manager_new ());
 	ToolsBox->SetUIManager (ToolsManager);
 	GtkActionGroup *action_group = gtk_action_group_new ("Tools");
 	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
 	gtk_action_group_add_radio_actions (action_group, RadioActions, m_entries, 0, G_CALLBACK (on_tool_changed), this);
-	gtk_ui_manager_insert_action_group (ToolsManager, action_group, 0);
+	gtk_ui_manager_insert_action_group (ToolsManager->GetUIManager (), action_group, 0);
 	for (j = UiDescs.begin (); j != jend; j++)
-		if (!gtk_ui_manager_add_ui_from_string (ToolsManager, *j, -1, &error)) {
+		if (!gtk_ui_manager_add_ui_from_string (ToolsManager->GetUIManager (), *j, -1, &error)) {
 			string what = string ("building user interface failed: ") + error->message;
 			g_error_free (error);
 			throw runtime_error (what);
@@ -985,12 +1004,11 @@ void Application::BuildTools () throw (std::runtime_error)
 		s += (*i).second;
 		ToolsBox->AddToolbar (s);
 	}
-	g_object_unref (ToolsManager);
 	m_pActiveTool = m_Tools["Select"];
 	if (m_pActiveTool)
 		m_pActiveTool->Activate(true);
-	ToolsBox->OnSelectTool (m_pActiveTool);	
-	ToolsBox->OnElementChanged (m_CurZ);	
+	ToolsBox->OnSelectTool (m_pActiveTool);
+	ToolsBox->OnElementChanged (m_CurZ);
 }
 
 void Application::ShowTools (bool visible)
@@ -1022,51 +1040,114 @@ void Application::AddActions (GtkRadioActionEntry const *entries, int nb, char c
 	if (ui_description)
 		UiDescs.push_back (ui_description);
 	if (icons) {
+		GtkCssProvider *provider = gtk_css_provider_get_default ();
+		GtkStyleContext *ctxt = gtk_style_context_new ();
+		GtkWidgetPath *path = gtk_widget_path_new ();
+		gtk_widget_path_append_type (path, GTK_TYPE_BUTTON);
+		gtk_style_context_set_path (ctxt, path);
+		gtk_widget_path_free (path);
+		gtk_style_context_add_provider (ctxt, GTK_STYLE_PROVIDER (provider), 1);
 		GtkIconSet *set;
 		GtkIconSource *src;
 		while (icons->name) {
-			GdkPixbuf *pixbuf = gdk_pixbuf_new_from_inline (-1, icons->data_24, false, NULL);
-			set = gtk_icon_set_new ();
-			src = gtk_icon_source_new ();
-			gtk_icon_source_set_size_wildcarded (src, true);
-			gtk_icon_source_set_state_wildcarded (src, false);
-			gtk_icon_source_set_direction_wildcarded (src, true);
+			GdkPixbuf *icon;
+			if (icons->data_24) {
+				GdkPixbuf *pixbuf = gdk_pixbuf_new_from_inline (-1, icons->data_24, false, NULL);
+				set = gtk_icon_set_new ();
+				src = gtk_icon_source_new ();
+				gtk_icon_source_set_size_wildcarded (src, true);
+				gtk_icon_source_set_state_wildcarded (src, false);
+				gtk_icon_source_set_direction_wildcarded (src, true);
 
-			for (int c = 0; c < 5; c++) {
-				GdkPixbuf *icon = gdk_pixbuf_copy (pixbuf);
-				// set the pixbuf color to the corresponding style for the style
-				unsigned char red, blue, green;
-				red = m_Style->fg[c].red >> 8;
-				green = m_Style->fg[c].green >> 8;
-				blue = m_Style->fg[c].blue >> 8;
-				unsigned char *line, *cur;
-				line = gdk_pixbuf_get_pixels (icon);
-				int i, j, rows, cols, rowstride;
-				cols = gdk_pixbuf_get_width (icon);
-				rows = gdk_pixbuf_get_height (icon);
-				rowstride = gdk_pixbuf_get_rowstride (icon);
-				for (i = 0; i < rows; i++) {
-					cur = line;
-					line += rowstride;
-					for (j = 0; j < cols; j++) {
-						cur[0] = cur[0] ^ red;
-						cur[1] = cur[1] ^ green;
-						cur[2] = cur[2] ^ blue;
-						cur += 4;
+				for (int c = 0; c < 5; c++) {
+				icon = gdk_pixbuf_copy (pixbuf);
+#if 0
+					// set the pixbuf color to the corresponding style for the style
+					unsigned char red, blue, green;
+					red = m_Style->fg[c].red >> 8;
+					green = m_Style->fg[c].green >> 8;
+					blue = m_Style->fg[c].blue >> 8;
+					unsigned char *line, *cur;
+					line = gdk_pixbuf_get_pixels (icon);
+					int i, j, rows, cols, rowstride;
+					cols = gdk_pixbuf_get_width (icon);
+					rows = gdk_pixbuf_get_height (icon);
+					rowstride = gdk_pixbuf_get_rowstride (icon);
+					for (i = 0; i < rows; i++) {
+						cur = line;
+						line += rowstride;
+						for (j = 0; j < cols; j++) {
+							cur[0] = cur[0] ^ red;
+							cur[1] = cur[1] ^ green;
+							cur[2] = cur[2] ^ blue;
+							cur += 4;
+						}
 					}
+#endif
+					gtk_icon_source_set_pixbuf (src, icon);
+					gtk_icon_source_set_state (src, static_cast <GtkStateType> (c));
+					gtk_icon_set_add_source (set, src);	/* copies the src */
+					g_object_unref (icon);
 				}
-				gtk_icon_source_set_pixbuf (src, icon);
-				gtk_icon_source_set_state (src, static_cast <GtkStateType> (c));
-				gtk_icon_set_add_source (set, src);	/* copies the src */
-				g_object_unref (icon);
+				gtk_icon_source_free (src);
+				gtk_icon_factory_add (IconFactory, icons->name, set);	/* keeps reference to set */
+				gtk_icon_set_unref (set);
+				g_object_unref (pixbuf);
+			} else if (icons->canvas) {
+				cairo_surface_t *surface;
+				cairo_t *cr;
+				set = gtk_icon_set_new ();
+				src = gtk_icon_source_new ();
+				gtk_icon_source_set_size_wildcarded (src, true);
+				gtk_icon_source_set_state_wildcarded (src, false);
+				gtk_icon_source_set_direction_wildcarded (src, true);
+				for (int c = 0; c < 7; c++) {
+					GtkStateFlags state;
+					switch (c) {
+					default:
+					case 0:
+						state = GTK_STATE_FLAG_NORMAL;
+						break;
+					case 1:
+						state = GTK_STATE_FLAG_ACTIVE;
+						break;
+					case 2:
+						state = GTK_STATE_FLAG_PRELIGHT;
+						break;
+					case 3:
+						state = GTK_STATE_FLAG_SELECTED;
+						break;
+					case 4:
+						state = GTK_STATE_FLAG_INSENSITIVE;
+						break;
+					case 5:
+						state = GTK_STATE_FLAG_INCONSISTENT;
+						break;
+					case 6:
+						state = GTK_STATE_FLAG_FOCUSED;
+						break;
+					}
+					GdkRGBA rgba;
+					gtk_style_context_get_color (ctxt, state, &rgba);
+					icon = gdk_pixbuf_new (GDK_COLORSPACE_RGB, true, 8, 24, 24);
+					surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, 24, 24);
+					cr = cairo_create (surface);
+					gtk_widget_set_state_flags (icons->canvas->GetWidget (), static_cast < GtkStateFlags > (c? 1 << (c - 1): 0), true);
+					icons->canvas->SetColor (GO_COLOR_FROM_GDK_RGBA (rgba));
+					icons->canvas->Render (cr, false);
+					go_cairo_convert_data_to_pixbuf (gdk_pixbuf_get_pixels (icon), cairo_image_surface_get_data (surface), 24, 24, 96);
+					gtk_icon_source_set_pixbuf (src, icon);
+					gtk_icon_source_set_state (src, static_cast <GtkStateType> (c));
+					gtk_icon_set_add_source (set, src);	/* copies the src */
+					g_object_unref (icon);
+				}
+				gtk_icon_source_free (src);
+				gtk_icon_factory_add (IconFactory, icons->name, set);	/* keeps reference to set */
+				gtk_icon_set_unref (set);
 			}
-		
-			gtk_icon_source_free (src);
-			gtk_icon_factory_add (IconFactory, icons->name, set);	/* keeps reference to set */
-			gtk_icon_set_unref (set);
-			g_object_unref (pixbuf);
 			icons++;
 		}
+		g_object_unref (ctxt);
 	}
 }
 
@@ -1141,6 +1222,7 @@ void Application::OnConfigChanged (GOConfNode *node, gchar const *name)
 	GCU_UPDATE_KEY ("compression", int, CompressionLevel, {})
 	bool CopyAsText;
 	GCU_UPDATE_KEY ("invert-wedge-hashes", bool, InvertWedgeHashes, UpdateAllTargets ();)
+	GCU_UPDATE_KEY ("use-atom-colors", bool, m_UseAtomColors, {})
 	GCU_UPDATE_KEY ("copy-as-text", bool, CopyAsText, ClipboardFormats = CopyAsText?GCP_CLIPBOARD_ALL: GCP_CLIPBOARD_NO_TEXT;)
 }
 
@@ -1156,8 +1238,13 @@ void Application::AddMimeType (list<string> &l, string const& mime_type)
 		g_warning ("Duplicate mime type: %s", mime_type.c_str ());
 }
 
-void Application::TestSupportedType (char const *mime_type)
+void Application::TestSupportedType (char const *mime_type, char const* babel_type, bool writeable)
 {
+	AddMimeType (m_SupportedMimeTypes, mime_type);
+	if (babel_type)
+		RegisterBabelType (mime_type, babel_type);
+	if (writeable)
+		AddMimeType (m_WriteableMimeTypes, mime_type);
 /*	OBFormat *f = OBConversion::FormatFromMIME (mime_type);
 	if (f != NULL) {
 		AddMimeType (m_SupportedMimeTypes, mime_type);
@@ -1186,7 +1273,7 @@ void Application::AddMenuCallback (BuildMenuCb cb)
 	m_MenuCbs.push_back (cb);
 }
 
-void Application::BuildMenu (GtkUIManager *manager)
+void Application::BuildMenu (gcu::UIManager *manager)
 {
 	list<BuildMenuCb>::iterator i, end = m_MenuCbs.end ();
 	for (i = m_MenuCbs.begin (); i != end; i++)
@@ -1198,4 +1285,10 @@ gcu::Document *Application::CreateNewDocument ()
 	return new Document (this, true, NULL);
 }
 
+void Application::ReceiveTargets (GtkClipboard *clipboard, GtkSelectionData *selection_data)
+{
+	on_receive_targets (clipboard, selection_data, this);
+}
+
+
 }	//	namespace gcp
