@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * atom.h 
+ * atom.h
  *
- * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2012 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -35,6 +35,11 @@
 #include <gcu/macros.h>
 
 /*!\file*/
+
+namespace gcu {
+class UIManager;
+}
+
 namespace gcp {
 
 class Bond;
@@ -270,14 +275,14 @@ Used to move and/or transform an object.
 */
 	virtual void Transform2D (gcu::Matrix2D& m, double x, double y);
 /*!
-@param UIManager: the GtkUIManager to populate.
+@param UIManager: the gcu::UIManager to populate.
 @param object the atom on which occured the mouse click.
 @param x x coordinate of the mouse click.
 @param y y coordinate of the mouse click.
 
 This method is called to build a contextual menu for the atom.
 */
-	bool BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y);
+	bool BuildContextualMenu (gcu::UIManager *UIManager, Object *object, double x, double y);
 /*!
 @param Mol: a pointer to a molecule
 
@@ -363,7 +368,7 @@ Used to retrieve the size of the ink rectangle of the atom symbol (if displayed)
 \a angle is absolute value of the angle between an horizontal line and the line joining
 the center and the top left or the bottom left vertex.
 The returned width value is actually half the full width. Height is the height.
-This method is used to avoid bonds lines extyending over their atoms symbols.
+This method is used to avoid bonds lines extending over their atoms symbols.
 */
 	void GetSymbolGeometry (double &width, double &height, double &angle, bool up) const;
 
@@ -380,6 +385,10 @@ This method is used to avoid bonds lines extyending over their atoms symbols.
 */
 	Bond *GetBondAtAngle (double angle);
 
+	bool UpdateStereoBonds ();
+	bool HasStereoBond () const;
+	Bond *GetNewmanBond () const;
+
 protected:
 /*!
 @param width the witdh of the atomic symbol.
@@ -390,6 +399,15 @@ Evaluates where lines representing bonds should end to not overload the symbol.
 */
 	void BuildSymbolGeometry (double width, double height, double ascent);
 
+/*!
+@param property the identity of the property as defined in objprops.h.
+@param value the value of the property as a string.
+
+Used by the gcu::Loader mechanism to load properties of atoms.
+@return true on success.
+*/
+	bool SetProperty (unsigned property, char const *value);
+
 private:
 	void UpdateAvailablePositions ();
 
@@ -426,6 +444,9 @@ private:
 	// special offset for underlying rectangle; will be removed in next version
 	double m_xROffs, m_yROffs;
 
+	// atom parity stuff
+	Atom *m_Bonded[4]; // always using positive parity
+
 protected:
 /*!
 Half the height of the "C" character.
