@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * mechanism-arrow.cc 
+ * mechanism-arrow.cc
  *
  * Copyright (C) 2009-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -21,15 +21,18 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
- 
+
 #include "config.h"
 #include "mechanism-arrow.h"
+#include "mechanism-step.h"
 #include <glib/gi18n.h>
 #include <gcp/atom.h>
 #include <gcp/bond.h>
 #include <gcp/document.h>
 #include <gcp/electron.h>
 #include <gcp/fragment.h>
+#include <gcp/mechanism-step.h>
+#include <gcp/molecule.h>
 #include <gcp/settings.h>
 #include <gcp/theme.h>
 #include <gcp/view.h>
@@ -40,7 +43,7 @@
 #include <cstring>
 
 namespace gcp {
-	
+
 gcu::TypeId MechanismArrowType;
 
 MechanismArrow::MechanismArrow ():
@@ -215,6 +218,7 @@ bool MechanismArrow::Load (xmlNodePtr node)
 		m_EndAtNewBondCenter = !strcmp (reinterpret_cast <char const *> (buf), "true");
 		xmlFree (buf);
 	}
+	doc->ObjectLoaded (this);
 	return true;
 }
 
@@ -442,7 +446,7 @@ void MechanismArrow::SetSelected (int state)
 	GOColor color;
 	if (state != SelStateSelected)
 		static_cast <gccv::BezierArrow *> (m_Item)->SetShowControls (false);
-	switch (state) {	
+	switch (state) {
 	case SelStateUnselected:
 		color = Color;
 		break;
@@ -483,7 +487,29 @@ void MechanismArrow::OnLoaded ()
 		m_Target->Link (this);
 	}
 	Lock (false);
-	GetParent ()->OnLoaded ();
+	Object *parent = dynamic_cast <MechanismStep *> (GetParent ());
+	if (!parent) {
+		// this will happen after pasting a partial selection
+		parent = new MechanismStep ();
+		Document *doc = static_cast <Document *> (GetDocument ());
+		doc->AddChild (parent);
+		parent->AddChild (this);
+	}
+	Molecule *mol = NULL, *mol1;
+	if (m_Source) { // otherwise, it is most probably a bug
+		mol = static_cast <Molecule *> (m_Source->GetMolecule ());
+		if (mol && mol->GetParent () != parent && mol->GetParent ()->GetParent () != parent)
+			parent->AddChild (mol);
+	}
+	if (m_Target && (mol1 = static_cast <Molecule *> (m_Target->GetMolecule ())) && mol1 != mol && mol1->GetParent () != parent && mol1->GetParent ()->GetParent () != parent)
+		parent->AddChild (mol1);
+	parent->OnLoaded ();
+}
+
+bool MechanismArrow::CanSelect () const
+{
+	WidgetData *data = static_cast <Document *> (GetDocument ())->GetView ()->GetData ();
+	return data->IsSelected (m_Source) && data->IsSelected (m_Target) && ((m_SourceAux)? data->IsSelected (m_SourceAux): true);
 }
 
 }	//	namespace gcp
