@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * reaction-prop.cc 
+ * reaction-prop.cc
  *
- * Copyright (C) 2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2007-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -27,6 +27,7 @@
 #include "reaction-prop.h"
 #include "reaction-arrow.h"
 #include <glib/gi18n-lib.h>
+#include <cstring>
 
 using namespace gcu;
 
@@ -35,7 +36,7 @@ namespace gcp {
 TypeId ReactionPropType = NoType;
 
 char const *ReactionPropRoles[] = {
-	N_("Unkown"),
+	N_("Unknown"),
 	N_("Catalyst"),
 	N_("Reactant"),
 	N_("Product"),
@@ -50,7 +51,7 @@ static unsigned RoleFromString (char const *role)
 {
 	unsigned res = REACTION_PROP_MAX;
 	while (res > REACTION_PROP_UNKNOWN &&
-		   !strcmp (ReactionPropRoles[--res], role));
+		   !strcmp (ReactionPropRoles[--res], role)) ;
 	return res;
 }
 
@@ -97,11 +98,16 @@ bool ReactionProp::Load (xmlNodePtr node)
 	return res;
 }
 
-bool ReactionProp::OnSignal (SignalId Signal, Object *Child)
+bool ReactionProp::OnSignal (SignalId Signal, G_GNUC_UNUSED Object *Child)
 {
 	if (Signal == OnChangedSignal && !HasChildren ())
 		delete this;
 	return true;
 }
 
+std::string ReactionProp::Name ()
+{
+	return _("Reaction property");
+}
+
 }	//	namespace gcp
