@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * residue.h 
+ * residue.h
  *
  * Copyright (C) 2007-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -70,7 +70,7 @@ Residue::~Residue ()
 {
 }
 
-void Residue::Load (xmlNodePtr node, bool ro)
+void Residue::Load (xmlNodePtr node, bool ro, gcu::Application *app)
 {
 	m_ReadOnly = ro;
 	m_Node = node;
@@ -91,7 +91,7 @@ void Residue::Load (xmlNodePtr node, bool ro)
 	static_cast <Document *> (m_Document)->SetLoading (true);
 	m_Molecule->Load (m_MolNode);
 	static_cast <Document *> (m_Document)->SetLoading (false);
-	gcu::Residue::Load (node);
+	gcu::Residue::Load (node, app);
 }
 
 bool Residue::operator== (gcu::Molecule const &mol) const
