@@ -1,11 +1,11 @@
-/* 
+/*
  * GChemPaint library
  * window.h
  *
- * Copyright (C) 2006-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -25,10 +25,14 @@
 #define GCP_WINDOW_H
 
 #include "target.h"
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkuimanager.h>
+#include <gtk/gtk.h>
 
 /*!\file*/
+
+namespace gcugtk {
+class UIManager;
+}
+
 namespace gcp {
 
 class Application;
@@ -40,6 +44,7 @@ associated with a view which might be itself associated with a window.
 */
 class Window: public Target
 {
+friend class WindowPrivate;
 public:
 /*!
 @param app the gcp::Application instance.
@@ -165,19 +170,6 @@ Sets the window title.
 */
 	void SetTitle (char const *title);
 /*!
-@param path the path to activate.
-@param activate whether to activate or deactivate.
-
-Activates or deactivates the menu item corresponding to \a path according
-to the value of \a activate. 
-
-To deactivate the "Paste" menu item, use:
-\code
-ActivateActionWidget ("/MainMenu/EditMenu/Paste", false);
-\endcode
-*/
-	void ActivateActionWidget (char const *path, bool activate); 
-/*!
 If the document has been modified since last saving, pops-up a dialog box to
 ask the user if he wants to save the document, to drop the changes or to abort
 closing.
@@ -190,12 +182,6 @@ Method called by the framework when the File/Page setup menu command is fired.
 */
 	void OnPageSetup ();
 
-protected:
-/*!
-The GtkUIManager associated with the window.
-*/
-	GtkUIManager* m_UIManager;
-
 private:
 	GtkWidget* m_Bar;	//GtkStatusBar
 	unsigned m_statusId;
