@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * libs/gcu/molecule.h
  *
- * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2012 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -46,6 +46,8 @@ friend class Chain;
 public:
 /*!
 @param Type the type id of a derived class
+@param ct the content type for the molecule (2d or 3d), defaults to
+ContentType3D.
 
 The constructor. The type id may be changed in derived classes, otherwise the
 argument is not needed, since the default value is enough.
@@ -53,6 +55,8 @@ argument is not needed, since the default value is enough.
 	Molecule (TypeId Type = MoleculeType, ContentType ct = ContentType3D);
 /*!
 @param pAtom
+@param ct the content type for the molecule (2d or 3d), defaults to
+ContentType3D.
 
 Builds a molecule from an atom. If the atom has bonds, the connectivity will
 be explored and all atoms and bonds found will be added to the molecule.
@@ -169,14 +173,34 @@ a given convention.
 */
 	std::string Name ();
 
+/*!
+Reinitialize all chemical identifiers for the molecule (InChI, InChIKey, and SMILES
+*/
 	void ResetIndentifiers ();
+
+/*!
+@return a CML representation of the molecule.
+*/
 	std::string const &GetCML ();
+
+/*!
+Clears all information related to cycles.
+*/
 	void ClearCycles ();
+
 /*!
 @return the InChI.
 */
 	std::string const &GetInChI ();
+
+/*!
+@return the InChIKey.
+*/
 	std::string const &GetInChIKey ();
+
+/*!
+@return the canonical SMILES for the molecule.
+*/
 	std::string const &GetSMILES ();
 /*!
 @return the raw formula as a string.
