@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
- * residue.cc 
+ * residue.cc
  *
  * Copyright (C) 2007-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -23,6 +23,7 @@
  */
 
 #include "config.h"
+#include "application.h"
 #include "document.h"
 #include "element.h"
 #include "molecule.h"
@@ -129,18 +130,18 @@ void Residue::RemoveSymbol (char const *symbol)
 		tbl.rtbs.erase (symbol);
 }
 
-void Residue::Load (xmlNodePtr node)
+void Residue::Load (xmlNodePtr node, Application *app)
 {
 	static char *lang = getenv ("LANG");
 	if (m_Name)
 		return;
-	char *buf = reinterpret_cast <char *> (xmlGetProp (node, reinterpret_cast <xmlChar const *> ("generic"))); 
+	char *buf = reinterpret_cast <char *> (xmlGetProp (node, reinterpret_cast <xmlChar const *> ("generic")));
 	if (buf) {
 		if (!strcmp (buf, "true"))
 			m_Generic = true;
 		xmlFree (buf);
 	}
-	buf = reinterpret_cast <char *> (xmlGetProp (node, reinterpret_cast <xmlChar const *> ("raw"))); 
+	buf = reinterpret_cast <char *> (xmlGetProp (node, reinterpret_cast <xmlChar const *> ("raw")));
 	if (buf) {
 		int i = 0, j = 1, n, z = strlen (buf);
 		char *end;
@@ -175,7 +176,9 @@ void Residue::Load (xmlNodePtr node)
 					xmlFree (name);
 				name = reinterpret_cast <char *> (xmlNodeGetContent (child));
 			}
-			m_Names[(node_lang)? node_lang: "C"] = reinterpret_cast <char const *> (xmlNodeGetContent (child));
+			buf = reinterpret_cast <char *> (xmlNodeGetContent (child));
+			m_Names[(node_lang)? node_lang: "C"] = buf;
+			xmlFree (buf);
 			if (node_lang)
 				xmlFree (node_lang);
 		} else if (!strcmp (reinterpret_cast <char const *> (child->name), "symbols")) {
@@ -200,9 +203,9 @@ void Residue::Load (xmlNodePtr node)
 			}
 			xmlFree (symbols);
 		} else if (!strcmp (reinterpret_cast <char const *> (child->name), "molecule") && m_Molecule == NULL) {
-			m_Document = dynamic_cast <Document *> (Object::CreateObject ("document"));
+			m_Document = dynamic_cast <Document *> (app->CreateObject ("document"));
 			if (m_Document) {
-				m_Molecule = dynamic_cast <Molecule *> (Object::CreateObject ("molecule", m_Document));
+				m_Molecule = dynamic_cast <Molecule *> (app->CreateObject ("molecule", m_Document));
 				if (m_Molecule)
 					m_Molecule->Load (child);
 			}
