@@ -23,6 +23,7 @@
  */
 
 #include "config.h"
+#include "ui-manager.h"
 #include "window.h"
 
 namespace gcu {
@@ -43,4 +44,9 @@ void Window::Show ()
 {
 }
 
+void Window::ActivateActionWidget (char const *path, bool activate)
+{
+	m_UIManager->ActivateActionWidget (path, activate);
+}
+
 }
