@@ -2,7 +2,7 @@
  * Gnome Chemisty Utils
  * spectrumview.h
  *
- * Copyright (C) 2007-2011 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2007-2012 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -31,7 +31,7 @@ namespace gcugtk
 
 class SpectrumDocument;
 
-/*!\class SpectrumView gcu/spectrumview.h
+/*!\class SpectrumView gcugtk/spectrumview.h
 The view class used for spectra. This API is still quite unstable and
 might change in the future.
 */
@@ -144,11 +144,25 @@ and pdf, and possibly a few other bitmap formats.
 */
 	void SaveAsImage (std::string const &filename, char const *mime_type, unsigned width, unsigned height) const;
 
+/*!
+@param w the widget to add to the view.
+
+Adds a widget to display more options to the view.
+*/
+	void AddToOptionBox (GtkWidget *w);
+
+/*!
+Destroys any widget that might have been added to  the view using
+AddToOptionBox().
+*/
+	void DestroyExtraWidget ();
+
 private:
 	GtkSpinButton *xminbtn, *xmaxbtn, *yminbtn, *ymaxbtn;
 	GtkRange *xrange, *yrange;
 	gulong minsgn, maxsgn, yminsgn, ymaxsgn, xrangesgn, yrangesgn;
 	double xmin, xmax, xstep, ymin, ymax, ystep;
+	GtkWidget *m_ExtraWidget;
 
 /*!\fn GetDoc()
 @return the associated document.
@@ -166,7 +180,13 @@ GCU_RO_PROP (GtkWidget *, OptionBox)
 @return the first GogSeries* created for the view.
 */
 GCU_RO_PROP (GogSeries *, Series)
+/*!\fn GetWidth()
+@return the view width.
+*/
 GCU_RO_PROP (int, Width)
+/*!\fn GetHeigth()
+@return the view height.
+*/
 GCU_RO_PROP (int, Height)
 };
 
