@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * CML files loader plugin
- * cml.cc 
+ * cml.cc
  *
  * Copyright (C) 2008-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -244,7 +244,7 @@ cml_simple_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 	}
 	state->cur.pop ();
 }
-	
+
 static void
 cml_scalar_start (GsfXMLIn *xin, G_GNUC_UNUSED xmlChar const **attrs)
 {
@@ -310,7 +310,7 @@ cml_mol_name_start (GsfXMLIn *xin, xmlChar const **attrs)
 			attrs++;
 		attrs++;
 	}
-	
+
 }
 
 static void
@@ -351,9 +351,36 @@ cml_atom_start (GsfXMLIn *xin, xmlChar const **attrs)
 			}
 			attrs++;
 		}
+	state->cur.push (obj);
 	state->doc->ObjectLoaded (obj);
 }
 
+static void
+cml_atom_parity_start (GsfXMLIn *xin, xmlChar const **attrs)
+{
+	CMLReadState *state = (CMLReadState *) xin->user_state;
+	if (attrs)
+		while (*attrs) {
+			if (!strcmp (reinterpret_cast < char const * > (*attrs), "atomRefs4")) {
+				attrs++;
+				state->curstr =  reinterpret_cast < char const * > (*attrs);
+			} else
+				attrs++;
+			attrs++;
+		}
+
+}
+
+static void
+cml_atom_parity_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
+{
+	CMLReadState *state = (CMLReadState *) xin->user_state;
+	string prop = xin->content->str;
+	prop += ' ';
+	prop += state->curstr;
+	state->cur.top ()->SetProperty (GCU_PROP_ATOM_PARITY, prop.c_str ());
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // Bond code
 
@@ -399,7 +426,7 @@ cml_bond_stereo (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 
 ////////////////////////////////////////////////////////////////////////////////
 // Crystal code
-	
+
 static void
 cml_crystal_start (GsfXMLIn *xin, G_GNUC_UNUSED xmlChar const **attrs)
 {
@@ -421,7 +448,7 @@ cml_crystal_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 	delete group;
 	state->data = NULL;
 };
-	
+
 static void
 cml_symmetry_start (GsfXMLIn *xin, G_GNUC_UNUSED xmlChar const **attrs)
 {
@@ -448,7 +475,7 @@ cml_transform_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 
 ////////////////////////////////////////////////////////////////////////////////
 // Molecule code
-	
+
 static void
 cml_mol_start (GsfXMLIn *xin, xmlChar const **attrs)
 {
@@ -461,7 +488,8 @@ cml_mol_start (GsfXMLIn *xin, xmlChar const **attrs)
 		GSF_XML_IN_NODE (MOL_PROPS, MOL_PROP, -1, "property", GSF_XML_NO_CONTENT, NULL, NULL),
 		GSF_XML_IN_NODE (MOL_PROP, MOL_PROP_SCALAR, -1, "scalar", GSF_XML_CONTENT, NULL, NULL),
 		GSF_XML_IN_NODE (MOL, ATOM_ARRAY, -1, "atomArray", GSF_XML_NO_CONTENT, NULL, NULL),
-			GSF_XML_IN_NODE (ATOM_ARRAY, ATOM, -1, "atom", GSF_XML_NO_CONTENT, cml_atom_start, NULL),
+			GSF_XML_IN_NODE (ATOM_ARRAY, ATOM, -1, "atom", GSF_XML_NO_CONTENT, cml_atom_start, cml_simple_end),
+				GSF_XML_IN_NODE (ATOM, ATOM_PARITY, -1, "atomParity", GSF_XML_CONTENT, cml_atom_parity_start, cml_atom_parity_end),
 		GSF_XML_IN_NODE (MOL, BOND_ARRAY, -1, "bondArray", GSF_XML_NO_CONTENT, NULL, NULL),
 			GSF_XML_IN_NODE (BOND_ARRAY, BOND, -1, "bond", GSF_XML_NO_CONTENT, cml_bond_start, cml_simple_end),
 				GSF_XML_IN_NODE (BOND, BOND_STEREO, -1, "bondStereo", GSF_XML_CONTENT, NULL, cml_bond_stereo),
