@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint arrows plugin
- * plugin.cc 
+ * plugin.cc
  *
  * Copyright (C) 2004-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -52,10 +52,6 @@ static Object* CreateRetrosynthesisStep ()
 
 gcpArrowsPlugin::gcpArrowsPlugin (): gcp::Plugin ()
 {
-	RetrosynthesisType = Object::AddType ("retrosynthesis", CreateRetrosynthesis);
-	Object::SetCreationLabel (RetrosynthesisType, _("Create a new retrosynthesis pathway"));
-	RetrosynthesisArrowType = Object::AddType ("retrosynthesis-arrow", CreateRetrosynthesisArrow);
-	RetrosynthesisStepType = Object::AddType ("retrosynthesis-step", CreateRetrosynthesisStep);
 }
 
 gcpArrowsPlugin::~gcpArrowsPlugin ()
@@ -63,13 +59,13 @@ gcpArrowsPlugin::~gcpArrowsPlugin ()
 }
 
 static gcp::IconDesc icon_descs[] = {
-	{"gcp_SimpleArrow", gcp_arrow1_24},
-	{"gcp_ReversibleArrow", gcp_arrow2_24},
-	{"gcp_RetrosynthesisArrow", gcp_retrosynth_24},
-	{"gcp_MesomeryArrow", gcp_mesomery_24},
-	{"gcp_CurvedArrow", gcp_curved_24},
-	{"gcp_Curved1Arrow", gcp_curved1_24},
-	{NULL, NULL},
+	{"gcp_SimpleArrow", gcp_arrow1_24, NULL},
+	{"gcp_ReversibleArrow", gcp_arrow2_24, NULL},
+	{"gcp_RetrosynthesisArrow", gcp_retrosynth_24, NULL},
+	{"gcp_MesomeryArrow", gcp_mesomery_24, NULL},
+	{"gcp_CurvedArrow", gcp_curved_24, NULL},
+	{"gcp_Curved1Arrow", gcp_curved1_24, NULL},
+	{NULL, NULL, NULL}
 };
 
 static GtkRadioActionEntry entries[] = {
@@ -107,6 +103,10 @@ static const char *ui_description =
 
 void gcpArrowsPlugin::Populate (gcp::Application* App)
 {
+	RetrosynthesisType = App->AddType ("retrosynthesis", CreateRetrosynthesis);
+	App->SetCreationLabel (RetrosynthesisType, _("Create a new retrosynthesis pathway"));
+	RetrosynthesisArrowType = App->AddType ("retrosynthesis-arrow", CreateRetrosynthesisArrow);
+	RetrosynthesisStepType = App->AddType ("retrosynthesis-step", CreateRetrosynthesisStep);
 	GOConfNode *node = go_conf_get_node (gcu::Application::GetConfDir (), "paint/plugins/arrows");
 	bool FullHeads = go_conf_get_bool (node, "full-arrows-heads");
 	go_conf_free_node (node);
@@ -118,10 +118,10 @@ void gcpArrowsPlugin::Populate (gcp::Application* App)
 	new gcpArrowTool (App, gcpDoubleQueuedArrow);
 	new gcpCurvedArrowTool (App, "CurvedArrow");
 	new gcpCurvedArrowTool (App, "Curved1Arrow");
-	Object::AddRule ("retrosynthesis", RuleMustContain, "retrosynthesis-step");
-	Object::AddRule ("retrosynthesis", RuleMustContain, "retrosynthesis-arrow");
-	Object::AddRule ("retrosynthesis-step", RuleMustContain, "molecule");
-	Object::AddRule ("molecule", RuleMayBeIn, "retrosynthesis-step");
-	Object::AddRule ("retrosynthesis-arrow", RuleMustBeIn, "retrosynthesis");
-	Object::AddRule ("retrosynthesis-step", RuleMustBeIn, "retrosynthesis");
+	App->AddRule ("retrosynthesis", RuleMustContain, "retrosynthesis-step");
+	App->AddRule ("retrosynthesis", RuleMustContain, "retrosynthesis-arrow");
+	App->AddRule ("retrosynthesis-step", RuleMustContain, "molecule");
+	App->AddRule ("molecule", RuleMayBeIn, "retrosynthesis-step");
+	App->AddRule ("retrosynthesis-arrow", RuleMustBeIn, "retrosynthesis");
+	App->AddRule ("retrosynthesis-step", RuleMustBeIn, "retrosynthesis");
 }
