@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint arrows plugin
  * retrosynthesis.cc
  *
- * Copyright (C) 2004-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -30,6 +30,7 @@
 #include <gcp/theme.h>
 #include <gcp/widgetdata.h>
 #include <gcp/view.h>
+#include <gcugtk/ui-manager.h>
 #include <glib/gi18n-lib.h>
 #include <cmath>
 #include <cstring>
@@ -59,7 +60,7 @@ gcpRetrosynthesis::~gcpRetrosynthesis ()
 			arrow->SetParent (GetParent ());
 			if (pOp)
 				pOp->AddObject (arrow, 1);
-			
+
 		} else
 			delete pObj;
 	}
@@ -132,14 +133,14 @@ typedef struct
 	gcpRetrosynthesisStep *step;
 } ObjectData;
 
-bool gcpRetrosynthesis::Build (list<Object*>& Children) throw (invalid_argument)
+bool gcpRetrosynthesis::Build (std::set < Object * > const &Children) throw (invalid_argument)
 {
 	gcp::Document *pDoc = reinterpret_cast<gcp::Document *> (GetDocument ());
 	gcp::Theme *pTheme = pDoc->GetTheme ();
 	gcp::WidgetData  *pData= reinterpret_cast<gcp::WidgetData *> (g_object_get_data (G_OBJECT (pDoc->GetWidget ()), "data"));
-	list<Object*>::iterator i, iend = Children.end ();
-	map<Object *, ObjectData> Objects;
-	list<Object *> Arrows;
+	set < Object * >::iterator i, iend = Children.end ();
+	map < Object *, ObjectData > Objects;
+	list < Object  * > Arrows;
 	double minright, minleft, x, y, x0, y0, x1, y1, l, d, ps;
 	Object *Left, *Right;
 	ObjectData od;
@@ -267,7 +268,7 @@ int gcpRetrosynthesis::Validate (bool split)
 {
 	map<string, Object*>::iterator i;
 	Object *pObj = GetFirstChild (i);
-	while (pObj && (pObj->GetType () != RetrosynthesisStepType || 
+	while (pObj && (pObj->GetType () != RetrosynthesisStepType ||
 		(reinterpret_cast<gcpRetrosynthesisStep *> (pObj))->GetArrow ()))
 		pObj = GetNextChild (i);
 	if (pObj == NULL)
@@ -281,12 +282,12 @@ int gcpRetrosynthesis::Validate (bool split)
 		if (!split)
 			return 2;
 		pObj = GetFirstChild (i);
-		while (pObj && (pObj->GetType () != RetrosynthesisStepType || 
+		while (pObj && (pObj->GetType () != RetrosynthesisStepType ||
 			(reinterpret_cast<gcpRetrosynthesisStep *> (pObj))->GetArrow () ||
 			pObj == Target))
 			pObj = GetNextChild (i);
 		if (reinterpret_cast<gcpRetrosynthesisStep *> (pObj)->Validate ()) {
-			gcpRetrosynthesis *rs = new gcpRetrosynthesis (GetParent (), 
+			gcpRetrosynthesis *rs = new gcpRetrosynthesis (GetParent (),
 								reinterpret_cast<gcpRetrosynthesisStep *> (pObj));
 			gcp::Document *pDoc = reinterpret_cast<gcp::Document*> (GetDocument ());
 			gcp::Operation *pOp = pDoc->GetCurrentOperation ();
@@ -409,17 +410,18 @@ static void do_destroy_retrosynthesis (void *data)
 	pDoc->FinishOperation ();
 }
 
-bool gcpRetrosynthesis::BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y)
+bool gcpRetrosynthesis::BuildContextualMenu (gcu::UIManager *UIManager, Object *object, double x, double y)
 {
+	GtkUIManager *uim = static_cast < gcugtk::UIManager * > (UIManager)->GetUIManager ();
 	GtkActionGroup *group = gtk_action_group_new ("retrosynthesis");
 	GtkAction *action = gtk_action_new ("destroy-rs", _("Destroy the retrosynthesis path"), NULL, NULL);
 	gtk_action_group_add_action (group, action);
 	g_object_unref (action);
-	gtk_ui_manager_insert_action_group (UIManager, group, 0);
+	gtk_ui_manager_insert_action_group (uim, group, 0);
 	g_object_unref (group);
 	char buf[] = "<ui><popup><menuitem action='destroy-rs'/></popup></ui>";
-	gtk_ui_manager_add_ui_from_string (UIManager, buf, -1, NULL);
-	GtkWidget *w = gtk_ui_manager_get_widget (UIManager, "/popup/destroy-rs");
+	gtk_ui_manager_add_ui_from_string (uim, buf, -1, NULL);
+	GtkWidget *w = gtk_ui_manager_get_widget (uim, "/popup/destroy-rs");
 	g_signal_connect_swapped (w, "activate", G_CALLBACK (do_destroy_retrosynthesis), this);
 	Object::BuildContextualMenu (UIManager, object, x, y);
 	return true;
