@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint arrows plugin
- * retrosynthesis.h 
+ * retrosynthesis.h
  *
- * Copyright (C) 2004-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -38,12 +38,12 @@ class gcpRetrosynthesis: public Object
 public:
 	gcpRetrosynthesis ();
 	virtual ~gcpRetrosynthesis ();
-	
+
 	virtual xmlNodePtr Save (xmlDocPtr xml) const;
 	virtual bool Load (xmlNodePtr);
-	virtual bool Build (std::list<Object*>& Children) throw (std::invalid_argument);
+	virtual bool Build (std::set < Object * > const &Children) throw (std::invalid_argument);
 	virtual double GetYAlign ();
-	virtual bool BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y);
+	virtual bool BuildContextualMenu (gcu::UIManager *UIManager, Object *object, double x, double y);
 	virtual bool OnSignal (SignalId Signal, Object *Child);
 	virtual void Transform2D (Matrix2D& m, double x, double y);
 	int Validate (bool split);
