@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint atoms plugin
- * orbitaltool.h 
+ * orbitaltool.h
  *
- * Copyright (C) 2002-2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2009-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -28,6 +28,11 @@
 #include <gcp/tool.h>
 #include "orbital.h"
 
+namespace gccv {
+	class Canvas;
+	class Item;
+}
+
 class gcpOrbitalTool: public gcp::Tool
 {
 public:
@@ -41,14 +46,22 @@ public:
 	void OnLeaveNotify ();
 	GtkWidget *GetPropertyPage ();
 	char const *GetHelpTag () {return "orbital";}
+	void UpdatePreview ();
 
 	// callbacks
 	static void CoefChanged (gcpOrbitalTool *tool, GtkSpinButton *btn);
+	static void TypeChanged (gcpOrbitalTool *tool, GtkToggleButton *btn);
+	static void RotationChanged (gcpOrbitalTool *tool, GtkSpinButton *btn);
+	static void SizeAllocate (gcpOrbitalTool *tool);
 
 private:
 	double m_Coef;
+	double m_Rotation;
 	gcpOrbitalType m_Type;
-	GtkSpinButton *m_CoefBtn;
+	GtkSpinButton *m_CoefBtn, *m_RotationBtn;
+	GtkWidget *m_RotationLbl;
+	gccv::Canvas *m_Preview;
+	gccv::Item *m_PreviewItem;
 };
 
 #endif	//GCHEMPAINT_ORBITAL_TOOL_H
