@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint bonds plugin
  * chaintool.h
  *
- * Copyright (C) 2006-2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -27,8 +27,7 @@
 
 #include <gcp/tool.h>
 #include <gccv/structs.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtktogglebutton.h>
+#include <gtk/gtk.h>
 #include <vector>
 
 namespace gcp {
@@ -41,7 +40,7 @@ class gcpChainTool: public gcp::Tool
 public:
 	gcpChainTool (gcp::Application *App);
 	virtual ~gcpChainTool ();
-	
+
 	bool OnClicked();
 	void OnDrag();
 	void OnRelease();
